==> FreeDoko_0.7.3.src.zip: FreeDoko_0.7.3/src/game/gameplay_actions.h <==
/**********************************************************************
 *
 *   FreeDoko a Doppelkopf-Game
 *    
 *   Copyright (C) 2001-2006  by Diether Knof and Borg Enders
 *
 *   This program is free software; you can redistribute it and/or 
 *   modify it under the terms of the GNU General Public License as 
 *   published by the Free Software Foundation; either version 2 of 
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details. 
 *   You can find this license in the file 'gpl.txt'.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
 *   MA  02111-1307  USA
 *
 *  Contact:
 *    Diether Knof dknof@gmx.de
 *    Borg Enders  borg@borgsoft.de
 *
 **********************************************************************/

#ifndef CLASS_GAMEPLAY_ACTIONS_HEADER
#define CLASS_GAMEPLAY_ACTIONS_HEADER

#include "gameplay_actions/reservation.h"
#include "gameplay_actions/poverty.h"
#include "gameplay_actions/card_played.h"
#include "gameplay_actions/announcement.h"
#include "gameplay_actions/swines.h"
#include "gameplay_actions/trick_full.h"
#include "gameplay_actions/trick_closed.h"
#include "gameplay_actions/marriage.h"
#include "gameplay_actions/genscher.h"

#endif // #ifndef CLASS_GAMEPLAY_ACTION_HEADER

==> FreeDoko_0.7.5.src.zip: FreeDoko_0.7.5/src/game/gameplay_actions.h <==
/**********************************************************************
 *
 *   FreeDoko a Doppelkopf-Game
 *    
 *   Copyright (C) 2001-2007  by Diether Knof and Borg Enders
 *
 *   This program is free software; you can redistribute it and/or 
 *   modify it under the terms of the GNU General Public License as 
 *   published by the Free Software Foundation; either version 2 of 
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details. 
 *   You can find this license in the file 'gpl.txt'.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
 *   MA  02111-1307  USA
 *
 *  Contact:
 *    Diether Knof dknof@gmx.de
 *    Borg Enders  borg@borgsoft.de
 *
 **********************************************************************/

#ifndef CLASS_GAMEPLAY_ACTIONS_HEADER
#define CLASS_GAMEPLAY_ACTIONS_HEADER

#include "gameplay_actions/reservation.h"
#include "gameplay_actions/poverty.h"
#include "gameplay_actions/card_played.h"
#include "gameplay_actions/announcement.h"
#include "gameplay_actions/swines.h"
#include "gameplay_actions/trick_open.h"
#include "gameplay_actions/trick_full.h"
#include "gameplay_actions/trick_taken.h"
#include "gameplay_actions/marriage.h"
#include "gameplay_actions/genscher.h"

#endif // #ifndef CLASS_GAMEPLAY_ACTION_HEADER
